Pygame Front Page — Pygame v1.9.4.dev0 documentation

##### pygame documentation | Pygame Home || Help Contents || Reference Index Color | cursors | display | draw | event | font | image | joystick | key | locals | mask | mixer | mouse | Rect | Surface | sprite | time | transform | BufferProxy | freetype | gfxdraw | midi | Overlay | PixelArray | pixelcopy | sndarray | surfarray | camera | cdrom | examples | math | music | pygame | scrap | tests | version

# Pygame Front Page

## Documents

Readme
  Basic information about Pygame, what it is, who is involved, and where to find it.
Install
  Steps needed to compile Pygame on several platforms. Also help on finding and installing prebuilt binaries for your system.
File Path Function Arguments
  How Pygame handles file system paths.
LGPL License
  This is the license Pygame is distributed under. It provides for Pygame to be distributed with open source and commercial software. Generally, if Pygame is not changed, it can be used with any type of program.

## Tutorials

Introduction to Pygame
  An introduction to the basics of Pygame. This is written for users of Python and appeared in volume two of the Py magazine.
Import and Initialize
  The beginning steps on importing and initializing Pygame. The Pygame package is made of several modules. Some modules are not included on all platforms.
How do I move an Image?
  A basic tutorial that covers the concepts behind 2D computer animation. Information about drawing and clearing objects to make them appear animated.
Chimp Tutorial, Line by Line
  The pygame examples include a simple program with an interactive fist and a chimpanzee. This was inspired by the annoying flash banner of the early 2000s. This tutorial examines every line of code used in the example.
Sprite Module Introduction
  Pygame includes a higher level sprite module to help organize games. The sprite module includes several classes that help manage details found in almost all games types. The Sprite classes are a bit more advanced than the regular Pygame modules, and need more understanding to be properly used.
Surfarray Introduction
  Pygame used the NumPy python module to allow efficient per pixel effects on images. Using the surface arrays is an advanced feature that allows custom effects and filters. This also examines some of the simple effects from the pygame example, arraydemo.py.
Camera Module Introduction
  Pygame, as of 1.9, has a camera module that allows you to capture images, watch live streams, and do some basic computer vision. This tutorial covers those use cases.
Newbie Guide
  A list of thirteen helpful tips for people to get comfortable using pygame.
Making Games Tutorial
  A large tutorial that covers the bigger topics needed to create an entire game.
Display Modes
  Getting a display surface for the screen.

## Reference

Index
  A list of all functions, classes, and methods in the pygame package.
pygame.BufferProxy
  An array protocol view of surface pixels
pygame.cdrom
  How to access and control the CD audio devices.
pygame.Color
  Color representation.
pygame.cursors
  Loading and compiling cursor images.
pygame.display
  Configure the display surface.
pygame.draw
  Drawing simple shapes like lines and ellipses to surfaces.
pygame.event
  Manage the incoming events from various input devices and the windowing platform.
pygame.examples
  Various programs demonstrating the use of individual pygame modules.
pygame.font
  Loading and rendering TrueType fonts.
pygame.freetype
  Enhanced Pygame module for loading and rendering font faces.
pygame.gfxdraw
  Anti-aliasing draw functions.
pygame.image
  Loading, saving, and transferring of surfaces.
pygame.joystick
  Manage the joystick devices.
pygame.key
  Manage the keyboard device.
pygame.locals
  Pygame constants.
pygame.mixer
  Load and play sounds
pygame.mouse
  Manage the mouse device and display.
pygame.mixer.music
  Play streaming music tracks.
pygame.Overlay
  Access advanced video overlays.
pygame
  Top level functions to manage Pygame.
pygame.PixelArray
  Manipulate image pixel data.
pygame.Rect
  Flexible container for a rectangle.
pygame.scrap
  Native clipboard access.
pygame.sndarray
  Manipulate sound sample data.
pygame.sprite
  Higher level objects to represent game images.
pygame.Surface
  Objects for images and the screen.
pygame.surfarray
  Manipulate image pixel data.
pygame.tests
  Test Pygame.
pygame.time
  Manage timing and framerate.
pygame.transform
  Resize and move images.
Search Page
  Search Pygame documents by keyword.